@@ -4,7 +4,7 @@ library(gradeR)
 # set working directory to place where you have
 # a. your grading file with the tests
 # b. all external .csv files that students use for their assignment
-setwd("~/gradeR/example/grading_resources/")
+setwd("~/gradeR/vignettes/example/grading_resources/")
 
 # this is the directory with all of the student submissions
 submissionDir <- "../submissions/"
